@@ -1,6 +1,6 @@
 from __future__ import absolute_import, print_function
 
-from .timer import Timer as _Timer
 from .__version__ import __version__, __version_info__
+from .timer import get_timer
 
-timer = _Timer
+timer = get_timer()
